@@ -1,6 +1,7 @@
 from jipso.Conversation import Conversation
 
-class Input:
+
+class Input(Conversation):
   """Manages information and data provided for AI processing.
   
   The Input component (I) represents objective reality - facts, data, content
@@ -12,5 +13,5 @@ class Input:
   integration and cross-platform information sharing through the import/export
   ecosystem.
   """
-  def __init__(self, content):
-    self.content = Conversation(content)
+  def __repr__(self) -> str:
+    return f'Input({len(self)} Message)'
