@@ -1,7 +1,7 @@
 from jipso.Conversation import Conversation
 
 
-class Standard:
+class Standard(Conversation):
   """Defines evaluation criteria and quality expectations.
   
   The Standard component (S) specifies WHAT constitutes good output - quality
@@ -14,5 +14,5 @@ class Standard:
   compliance frameworks, and systematic quality assurance standards from
   industry and academic institutions.
   """
-  def __init__(self, content):
-    self.content = Conversation(content)
\ No newline at end of file
+  def __repr__(self) -> str:
+    return f'Standard({len(self)} Message)'
